@@ -34,7 +34,8 @@ records = [
     record("0.5.4",link,"Photon Rain",2013,07,31),
     record("0.5.5",link,"Nights Without Convergence",2014,04,01),
     record("0.5.6",link,"Photon Calibration",2015,01,05),
-    record("0.5.7",link,"Growth Curve",2016,10,25)
+    record("0.5.7",link,"Growth Curve",2016,10,25),
+    record("0.5.8",link,"Artificial Sky",2017,07,14)
 ]
 
 for r in records:
